<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>new</translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>Never</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>Each turn</numerusform>
            <numerusform>Every %1 turns</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation>Edit weapons</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Illegal ammo scheme</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation>Edit schemes</translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation>%1 *** %2 has been removed from your ignore list</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation>%1 *** %2 has been added to your ignore list</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation>%1 *** %2 has been removed from your friends list</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation>%1 *** %2 has been added to your friends list</translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>new</source>
        <translation>new</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>Unable to start the server</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Cannot save record to file %1</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Please select record from the list above</translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>en.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>Cannot open demofile %1</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Map</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Themes</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>All</source>
        <translation>All</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Small</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Large</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Cavern</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Wacky</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Type</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Title</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>The host was not found. Please check the host name and port settings.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Connection refused</translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Room destroyed</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Quit reason:</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>You got kicked</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 has joined the room</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 has joined</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 has left (%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 has left</translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">Server message:</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">Set message</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>Clear Accounts Cache</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>Connecting...</translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Advanced</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kill in a turn.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog was killed during this round.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehogs were killed during this round.&lt;/p&gt;</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Local Game (Play a game on a single computer)</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Network Game (Play a game across a network)</translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Please select server from the list above</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>LAN game</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>Official server</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>New team</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Edit team</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation>Delete team</translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation>New weapon scheme</translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation>Edit weapon scheme</translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation>Delete weapon scheme</translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Rename dialog</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Enter new file name:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Cannot rename to</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Cannot delete file</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Please select record from the list</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Create</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Join</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Refresh</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>Administration</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>Room Name:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>This game is in lobby.
You may join and start playing once the game starts.</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 is the host. He may adjust settings and start the game.</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>Random Map</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>Games may be played on precreated or randomized maps.</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>The Weapon Scheme defines available weapons and their ammunition count.</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>There is %1 client connected to this room.</numerusform>
            <numerusform>There are %1 clients connected to this room.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>There is %1 team participating in this room.</numerusform>
            <numerusform>There are %1 teams participating in this room.</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Please enter room name</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Please select room from the list</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>Defend your fort and destroy the opponents, two team colours max!</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>Teams will start on opposite sides of the terrain, two team colours max!</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>Land can not be destroyed!</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation>Add an indestructable border around the terrain</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>Lower gravity</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>Assisted aiming with laser sight</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>All hogs have a personal forcefield</translation>
    </message>
    <message>
        <source>Enable random mines</source>
        <translation>Enable random mines</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>Gain 80% of the damage you do back in health</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>Share your opponents pain, share their damage</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>Your hogs are unable to move, put your artillery skills to the test</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Random</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Seconds</translation>
    </message>
    <message>
        <source>New</source>
        <translation>New</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>Order of play is random instead of in room order.</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>Play with a King. If he dies, your side dies.</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>Take turns placing your hedgehogs before the start of play.</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>Ammo is shared between all teams that share a colour.</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>Disable girders when generating random maps.</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Simple Game (a quick game against the computer, settings are chosen for you)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Multiplayer (play a hotseat game against your friends, or AI teams)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demos (Watch recorded demos)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Load (Load a previously saved game)</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Kick</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Restrict Joins</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Restrict Team Additions</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>Ban</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>Follow</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignore</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>Add friend</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>Unignore</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>Remove friend</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Check for updates at startup</source>
        <translation>Check for updates at startup</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullscreen</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Frontend fullscreen</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Enable sound</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Enable music</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>Show FPS</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Alternative damage show</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Append date and time to record file name</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation>Reduced quality</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>Show ammo menu tooltips</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>Enable frontend sounds</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>Enable frontend music</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>Frontend effects</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>generated map...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Human</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Level</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(System default)</translation>
    </message>
    <message>
        <source>Mission</source>
        <translation>Mission</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Team Members</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Fort</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Key binds</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Teams</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Weapons</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Audio/Graphic options</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Net game</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Playing teams</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>Game Modifiers</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Basic Settings</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>Team Settings</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Misc</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Mines Time</source>
        <translation>Mines Time</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>Mines</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>This program is distributed under the GNU General Public License</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Developers:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Art:</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Sounds:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Translations:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Special thanks:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Weapons</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Net nick</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolution</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>FPS limit</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Server name:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Server port:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Initial sound volume</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>Damage Modifier</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>Turn Time</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>Initial Health</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>Sudden Death Timeout</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>Scheme Name:</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>Crate Drops</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>Game scheme</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% Dud Mines</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>Grave</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>Flag</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Voice</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Locale</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>Restart game to apply</translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation>Explosives</translation>
    </message>
    <message>
        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
Some features might be broken or incomplete. Use at your own risk!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>unnamed</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Hedgewars %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Network</source>
        <translation>Network</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>Connection to server is lost</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Failed to open data directory:
 %1
Please check your installation</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Weapons</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation>Can not edit default weapon set</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation>Can not delete default weapon set</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>Really delete this weapon set?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Cannot create directory %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nickname</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>Please enter your nickname</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>default</source>
        <translation>default</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Start server</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Connect</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Update</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Specify</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Go!</source>
        <translation>Go!</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Play demo</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rename</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Load</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Setup</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Ready</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>Random Team</translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>Room Name</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Owner</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Map</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>Rules</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Weapons</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>Weapon set</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>Probabilities</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>Ammo in boxes</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>Delays</translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Unable to start the server: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Unable to run engine: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>Vampirism</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>Karma</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>Artillery</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>Fort Mode</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>Divide Teams</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>Solid Land</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>Add Border</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>Low Gravity</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>Laser Sight</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>Invulnerable</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation>Add Mines</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>Random Order</translation>
    </message>
    <message>
        <source>King</source>
        <translation>King</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>Place Hedgehogs</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>Clan Shares Ammo</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>Disable Girders</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>up</translation>
    </message>
    <message>
        <source>left</source>
        <translation>left</translation>
    </message>
    <message>
        <source>right</source>
        <translation>right</translation>
    </message>
    <message>
        <source>down</source>
        <translation>down</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>attack</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>precise aim</translation>
    </message>
    <message>
        <source>put</source>
        <translation>put</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>switch</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>find hedgehog</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>ammo menu</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>slot 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>slot 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>slot 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>slot 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>slot 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>slot 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>slot 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>slot 8</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>slot 9</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>timer 1 sec</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>timer 2 sec</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>timer 3 sec</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>timer 4 sec</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>timer 5 sec</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>chat</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>chat history</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>pause</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>confirmation</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>volume down</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>volume up</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>change mode</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>capture</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>hedgehogs
info</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>quit</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>zoom in</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>zoom out</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>reset zoom</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>long jump</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>high jump</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>Basic controls</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>Weapon controls</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>Camera and cursor controls</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Other</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>Move your hogs and aim:</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>Traverse gaps and obstacles by jumping:</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>Fire your selected weapon or trigger an utility item:</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>Pick a weapon or a target location under the cursor:</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>Switch your currently active hog (if possible):</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>Pick a weapon or utility item:</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>Set the timer on bombs and timed weapons:</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation>Move the camera to the active hog:</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>Move the cursor or camera without using the mouse:</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>Modify the camera&apos;s zoom level:</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>Talk to your team or all participants:</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>Pause, continue or leave your game:</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>Modify the game&apos;s volume while playing:</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>Toggle fullscreen mode:</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>Take a screenshot:</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>Toggle labels above hedgehogs:</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Escape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Equals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPad</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
